@@ -16,10 +16,10 @@
 
   if (faminfo$family %in% c("truncated_nbinom1")) {
     if (verbose) {
-      warning(format_message(sprintf(
+      format_warning(sprintf(
         "Truncated negative binomial families are currently not supported by `%s`.",
         name_fun
-      )), call. = FALSE)
+      ))
     }
     return(NA)
   }
@@ -38,10 +38,10 @@
   no_random_variance <- FALSE
   if (.is_singular(x, vals, tolerance = tolerance) && !(component %in% c("slope", "intercept"))) {
     if (verbose) {
-      warning(format_message(
+      format_warning(
         sprintf("Can't compute %s. Some variance components equal zero. Your model may suffer from singularity (see `?lme4::isSingular` and `?performance::check_singularity`).", name_full),
         "Solution: Respecify random structure! You may also decrease the `tolerance` level to enforce the calculation of random effect variances."
-      ), call. = FALSE)
+      )
     }
     no_random_variance <- TRUE
   }
@@ -64,14 +64,14 @@
 
   # Are random slopes present as fixed effects? Warn.
   if (!.random_slopes_in_fixed(x) && verbose) {
-    warning(format_message(
+    format_warning(
       sprintf("Random slopes not present as fixed effects. This artificially inflates the conditional %s.", name_full),
       "Solution: Respecify fixed structure!"
-    ), call. = FALSE)
+    )
   }
 
   # Separate observation variance from variance of random effects
-  nr <- sapply(vals$re, nrow)
+  nr <- vapply(vals$re, nrow, numeric(1))
   not.obs.terms <- names(nr[nr != n_obs(x)])
   obs.terms <- names(nr[nr == n_obs(x)])
 
@@ -199,14 +199,14 @@
     vc1 <- vc2 <- NULL
     re_names <- find_random(x)
 
-    vc_cond <- !grepl("^zi_", colnames(x$D))
+    vc_cond <- !startsWith(colnames(x$D), "zi_")
     if (any(vc_cond)) {
       vc1 <- x$D[vc_cond, vc_cond, drop = FALSE]
       attr(vc1, "stddev") <- sqrt(diag(vc1))
       attr(vc1, "correlation") <- stats::cov2cor(x$D[vc_cond, vc_cond, drop = FALSE])
     }
 
-    vc_zi <- grepl("^zi_", colnames(x$D))
+    vc_zi <- startsWith(colnames(x$D), "zi_")
     if (any(vc_zi)) {
       colnames(x$D) <- gsub("^zi_(.*)", "\\1", colnames(x$D))
       rownames(x$D) <- colnames(x$D)
@@ -386,9 +386,9 @@
 # is supported or not
 .badlink <- function(link, family, verbose = TRUE) {
   if (verbose) {
-    warning(format_message(sprintf(
+    format_warning(sprintf(
       "Model link `%s` is not yet supported for the %s distribution.", link, family
-    )), call. = FALSE)
+    ))
   }
   return(NA)
 }
@@ -441,7 +441,7 @@
     rn <- rownames(Sigma)
 
     # fix for models w/o intercept
-    if (!any(grepl("^\\(Intercept\\)", colnames(vals$X)))) {
+    if (!any(startsWith(colnames(vals$X), "(Intercept)"))) {
       vals$X <- cbind("(Intercept)" = 1, vals$X)
     }
 
@@ -584,9 +584,7 @@
 # on the lognormal-approximation.
 #
 .variance_distributional <- function(x, faminfo, sig, name, verbose = TRUE) {
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("Package `lme4` needs to be installed to compute variances for mixed models.", call. = FALSE)
-  }
+  check_if_installed("lme4", "to compute variances for mixed models")
 
   # lognormal-approximation of distributional variance,
   # see Nakagawa et al. 2017
@@ -610,16 +608,16 @@
 
   if (is.na(mu)) {
     if (verbose) {
-      warning(format_message(
+      format_warning(
         "Can't calculate model's distribution-specific variance. Results are not reliable."
-      ), call. = FALSE)
+      )
     }
     return(0)
   } else if (mu < 6) {
     if (verbose) {
-      warning(format_message(
+      format_warning(
         sprintf("mu of %0.1f is too close to zero, estimate of %s may be unreliable.", mu, name)
-      ), call. = FALSE)
+      )
     }
   }
 
@@ -663,17 +661,17 @@
       )
 
       if (vv < 0 && isTRUE(verbose)) {
-        warning(format_message(
+        format_warning(
           "Model's distribution-specific variance is negative. Results are not reliable."
-        ), call. = FALSE)
+        )
       }
       vv / mu^2
     },
     error = function(x) {
       if (verbose) {
-        warning(format_message(
+        format_warning(
           "Can't calculate model's distribution-specific variance. Results are not reliable."
-        ), call. = FALSE)
+        )
       }
       0
     }
@@ -904,7 +902,7 @@
 .between_subject_variance <- function(vals, x) {
   vars <- lapply(vals$vc, function(i) i[1])
   # check for uncorrelated random slopes-intercept
-  non_intercepts <- which(sapply(vals$vc, function(i) !grepl("^\\(Intercept\\)", dimnames(i)[[1]][1])))
+  non_intercepts <- which(sapply(vals$vc, function(i) !startsWith(dimnames(i)[[1]][1], "(Intercept)")))
   if (length(non_intercepts)) {
     vars <- vars[-non_intercepts]
   }
@@ -925,7 +923,7 @@
     # random slopes for correlated slope-intercept
     out <- unlist(lapply(vals$vc, function(x) diag(x)[-1]))
     # check for uncorrelated random slopes-intercept
-    non_intercepts <- which(sapply(vals$vc, function(i) !grepl("^\\(Intercept\\)", dimnames(i)[[1]][1])))
+    non_intercepts <- which(sapply(vals$vc, function(i) !startsWith(dimnames(i)[[1]][1], "(Intercept)")))
     if (length(non_intercepts) == length(vals$vc)) {
       out <- unlist(lapply(vals$vc, function(x) diag(x)))
     } else if (length(non_intercepts)) {
