@@ -123,7 +123,7 @@ find_formula.list <- function(x, verbose = TRUE, ...) {
 
 #' @export
 find_formula.data.frame <- function(x, verbose = TRUE, ...) {
-  stop("A data frame is not a valid object for this function.", call. = FALSE)
+  format_error("A data frame is not a valid object for this function.")
 }
 
 
@@ -137,7 +137,7 @@ find_formula.aovlist <- function(x, verbose = TRUE, ...) {
 
 #' @export
 find_formula.anova <- function(x, verbose = TRUE, ...) {
-  stop("Formulas cannot be retrieved from anova() objects.", call. = FALSE)
+  format_error("Formulas cannot be retrieved from anova() objects.")
 }
 
 
@@ -1196,7 +1196,7 @@ find_formula.sem <- function(x, verbose = TRUE, ...) {
 
 #' @export
 find_formula.lme <- function(x, verbose = TRUE, ...) {
-  fm <- eval(x$call$fixed)
+  fm <- stats::formula(x$terms)
   fmr <- eval(x$call$random)
   ## TODO this is an intermediate fix to return the correlation variables from lme-objects
   fcorr <- x$call$correlation
@@ -1422,11 +1422,14 @@ find_formula.BFBayesFactor <- function(x, verbose = TRUE, ...) {
       for (i in frand) {
         fcond <- sub(i, "", fcond, fixed = TRUE)
       }
-      while (grepl("\\+$", trim_ws(fcond))) {
+      while (grepl("(\\+)\\s+\\1", trim_ws(fcond))) {
+        fcond <- gsub("(\\+)\\s+\\1", "\\1", trim_ws(fcond))
+      }
+      while (endsWith(trim_ws(fcond), "+")) {
         fcond <- gsub("(.*)\\+$", "\\1", trim_ws(fcond))
       }
       # random effects only?
-      if (grepl("~$", trim_ws(fcond))) {
+      if (endsWith(trim_ws(fcond), "~")) {
         fcond <- paste(fcond, "1")
       }
       f.cond <- stats::as.formula(trim_ws(fcond))
@@ -1721,12 +1724,9 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
 
   if (grepl("(.*)poly\\((.*),\\s*raw\\s*=\\s*T\\)", f)) {
     if (verbose) {
-      warning(
-        format_message(
-          "Looks like you are using 'poly()' with 'raw = T'. This results in unexpected behaviour, because 'all.vars()' considers 'T' as variable.",
-          "Please use 'raw = TRUE'."
-        ),
-        call. = FALSE
+      format_warning(
+        "Looks like you are using `poly()` with \"raw = T\". This results in unexpected behaviour, because `all.vars()` considers `T` as variable.",
+        "Please use \"raw = TRUE\"."
       )
     }
     return(FALSE)
@@ -1744,19 +1744,16 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
     return(TRUE)
   }
 
-  if (any(grepl("\\$", safe_deparse(f[[1]])))) {
+  if (any(grepl("$", safe_deparse(f[[1]]), fixed = TRUE))) {
     fc <- try(.formula_clean(f[[1]]), silent = TRUE)
     if (inherits(fc, "try-error")) {
-      stop(attributes(fc)$condition$message, call. = FALSE)
+      format_error(attributes(fc)$condition$message)
     } else {
       if (verbose) {
-        warning(
-          format_message(paste0(
-            "Using `$` in model formulas can produce unexpected results. Specify your model using the `data` argument instead.",
-            "\n  Try: ", fc$formula, ", data = ", fc$data
-          )),
-          call. = FALSE
-        )
+        format_warning(paste0(
+          "Using `$` in model formulas can produce unexpected results. Specify your model using the `data` argument instead.",
+          "\n  Try: ", fc$formula, ", data = ", fc$data
+        ))
       }
       return(FALSE)
     }
@@ -1779,7 +1776,7 @@ find_formula.model_fit <- function(x, verbose = TRUE, ...) {
   d_RHS <- unique(gsub("(.*)\\$(.*)", "\\1", parts[grepl("(.*)\\$(.*)", parts)]))
 
   if (n_unique(c(d_LHS, d_RHS)) > 1) {
-    stop("Multiple data objects present in formula. Specify your model using the `data` argument instead.", call. = FALSE)
+    format_error("Multiple data objects present in formula. Specify your model using the `data` argument instead.")
   } else {
     d <- unique(d_RHS)
   }
