@@ -151,7 +151,7 @@ get_parameters.cgam <- function(x, component = c("all", "conditional", "smooth_t
 #' @export
 get_parameters.SemiParBIV <- function(x, ...) {
   s <- summary(x)
-  s <- compact_list(s[grepl("^tableP", names(s))])
+  s <- compact_list(s[startsWith(names(s), "tableP")])
   params <- do.call(rbind, lapply(seq_along(s), function(i) {
     out <- as.data.frame(s[[i]])
     out$Parameter <- rownames(out)
