@@ -233,6 +233,12 @@ n_parameters.stanmvreg <- n_parameters.stanreg
 # Other models -------------------------------------
 
 
+#' @export
+n_parameters.gls <- function(x, ...) {
+  x$dims[["p"]]
+}
+
+
 #' @export
 n_parameters.lavaan <- function(x, ...) {
   # TODO
