@@ -28,6 +28,12 @@ if (!osx && requiet("testthat") &&
     expect_true(model_info(m1)$is_linear)
   })
 
+  m_tmp <- m1
+  m_tmp$vcov_arg <- "Normal standard errors"
+  test_that("get_varcov", {
+    expect_equal(vcov(m_tmp, scale = TRUE), get_varcov(m1), tolerance = 1e-3)
+  })
+
   test_that("find_predictors", {
     expect_identical(find_predictors(m1), list(
       conditional = c("marry", "enrol", "yeargr"),
@@ -75,6 +81,24 @@ if (!osx && requiet("testthat") &&
     )
   })
 
+  test_that("get_df", {
+    expect_equal(
+      get_df(m1, type = "residual"),
+      df.residual(m1),
+      ignore_attr = TRUE
+    )
+    expect_equal(
+      get_df(m1, type = "normal"),
+      Inf,
+      ignore_attr = TRUE
+    )
+    expect_equal(
+      get_df(m1, type = "wald"),
+      2290,
+      ignore_attr = TRUE
+    )
+  })
+
   test_that("find_formula", {
     expect_length(find_formula(m1), 3)
     expect_equal(
